@@ -263,7 +263,13 @@ def parser(literal_string, ident, sqlserver=False):
             + Optional(assign("nulls", keyword("first") | keyword("last")))
         )
 
-        one_param = Group(ident + Literal("=>").suppress() + Group(expression))("kwargs") / to_kwarg | Group(expression)("params")
+        one_param = (
+            # KEYWORD PARAMETERS?
+            # https://docs.snowflake.com/en/sql-reference/functions/generator.html
+            Group(ident + Literal("=>").suppress() + Group(expression))("kwargs")
+            / to_kwarg
+        ) | Group(expression)("params")
+
         call_function = (
             function_name("op")
             + LB
@@ -481,8 +487,10 @@ def parser(literal_string, ident, sqlserver=False):
         #
         # <unpivot_clause> ::=
         #     ( value_column FOR pivot_column IN ( <column_list> ) )
+        lateral_source = (LATERAL("op")+table_source("params"))/to_json_call
+
         table_source << Group(
-            ((LB + query + RB) | unnest | stack | call_function | identifier)("value")
+            (lateral_source | (LB + query + RB) | unnest | stack | call_function | identifier)("value")
             + MatchAll([
                 Optional(flag("with ordinality")),
                 Optional(WITH + LB + keyword("nolock")("hint") + RB),
@@ -579,8 +587,7 @@ def parser(literal_string, ident, sqlserver=False):
         )
         temporary = Optional(
             (
-                Keyword("temporary", caseless=True)
-                | Keyword("temp", caseless=True)
+                Keyword("temporary", caseless=True) | Keyword("temp", caseless=True)
             )("temporary")
             / (lambda: True)
         ) + Optional(flag("transient"))
